==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/GitSourceRevisionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class GitSourceRevisionFluentImpl<A extends io.fabric8.openshift.api.model.GitSourceRevisionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.GitSourceRevisionFluent<A>{
  public GitSourceRevisionFluentImpl() {
  }
  public GitSourceRevisionFluentImpl(io.fabric8.openshift.api.model.GitSourceRevision instance) {
    this.withAuthor(instance.getAuthor()); 
    this.withCommit(instance.getCommit()); 
    this.withCommitter(instance.getCommitter()); 
    this.withMessage(instance.getMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SourceControlUserBuilder author;
  private java.lang.String commit;
  private io.fabric8.openshift.api.model.SourceControlUserBuilder committer;
  private java.lang.String message;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthor instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceControlUser getAuthor() {
    return this.author!=null?this.author.build():null;
  }
  public io.fabric8.openshift.api.model.SourceControlUser buildAuthor() {
    return this.author!=null?this.author.build():null;
  }
  public A withAuthor(io.fabric8.openshift.api.model.SourceControlUser author) {
    _visitables.get("author").remove(this.author);
    if (author!=null){ this.author= new io.fabric8.openshift.api.model.SourceControlUserBuilder(author); _visitables.get("author").add(this.author);} return (A) this;
  }
  public java.lang.Boolean hasAuthor() {
    return this.author != null;
  }
  public A withNewAuthor(java.lang.String email,java.lang.String name) {
    return (A)withAuthor(new SourceControlUser(email, name));
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> withNewAuthor() {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.AuthorNestedImpl();
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> withNewAuthorLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.AuthorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> editAuthor() {
    return withNewAuthorLike(getAuthor());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> editOrNewAuthor() {
    return withNewAuthorLike(getAuthor() != null ? getAuthor(): new io.fabric8.openshift.api.model.SourceControlUserBuilder().build());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> editOrNewAuthorLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return withNewAuthorLike(getAuthor() != null ? getAuthor(): item);
  }
  public java.lang.String getCommit() {
    return this.commit;
  }
  public A withCommit(java.lang.String commit) {
    this.commit=commit; return (A) this;
  }
  public java.lang.Boolean hasCommit() {
    return this.commit != null;
  }
  
  /**
   * Method is deprecated. use withCommit instead.
   */
  @java.lang.Deprecated
  public A withNewCommit(java.lang.String arg0) {
    return (A)withCommit(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCommitter instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceControlUser getCommitter() {
    return this.committer!=null?this.committer.build():null;
  }
  public io.fabric8.openshift.api.model.SourceControlUser buildCommitter() {
    return this.committer!=null?this.committer.build():null;
  }
  public A withCommitter(io.fabric8.openshift.api.model.SourceControlUser committer) {
    _visitables.get("committer").remove(this.committer);
    if (committer!=null){ this.committer= new io.fabric8.openshift.api.model.SourceControlUserBuilder(committer); _visitables.get("committer").add(this.committer);} return (A) this;
  }
  public java.lang.Boolean hasCommitter() {
    return this.committer != null;
  }
  public A withNewCommitter(java.lang.String email,java.lang.String name) {
    return (A)withCommitter(new SourceControlUser(email, name));
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> withNewCommitter() {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.CommitterNestedImpl();
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> withNewCommitterLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.CommitterNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> editCommitter() {
    return withNewCommitterLike(getCommitter());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> editOrNewCommitter() {
    return withNewCommitterLike(getCommitter() != null ? getCommitter(): new io.fabric8.openshift.api.model.SourceControlUserBuilder().build());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> editOrNewCommitterLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return withNewCommitterLike(getCommitter() != null ? getCommitter(): item);
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitSourceRevisionFluentImpl that = (GitSourceRevisionFluentImpl) o;
    if (author != null ? !author.equals(that.author) :that.author != null) return false;
    if (commit != null ? !commit.equals(that.commit) :that.commit != null) return false;
    if (committer != null ? !committer.equals(that.committer) :that.committer != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(author,  commit,  committer,  message,  additionalProperties,  super.hashCode());
  }
  public class AuthorNestedImpl<N> extends io.fabric8.openshift.api.model.SourceControlUserFluentImpl<io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<N>> implements io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AuthorNestedImpl(io.fabric8.openshift.api.model.SourceControlUser item) {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this, item);
    }
    AuthorNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this);
    }
    io.fabric8.openshift.api.model.SourceControlUserBuilder builder;
    public N and() {
      return (N) GitSourceRevisionFluentImpl.this.withAuthor(builder.build());
    }
    public N endAuthor() {
      return and();
    }
    
  }
  public class CommitterNestedImpl<N> extends io.fabric8.openshift.api.model.SourceControlUserFluentImpl<io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<N>> implements io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CommitterNestedImpl(io.fabric8.openshift.api.model.SourceControlUser item) {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this, item);
    }
    CommitterNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this);
    }
    io.fabric8.openshift.api.model.SourceControlUserBuilder builder;
    public N and() {
      return (N) GitSourceRevisionFluentImpl.this.withCommitter(builder.build());
    }
    public N endCommitter() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/GitSourceRevisionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class GitSourceRevisionFluentImpl<A extends io.fabric8.openshift.api.model.GitSourceRevisionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.GitSourceRevisionFluent<A>{
  public GitSourceRevisionFluentImpl() {
  }
  public GitSourceRevisionFluentImpl(io.fabric8.openshift.api.model.GitSourceRevision instance) {
    this.withAuthor(instance.getAuthor()); 
    this.withCommit(instance.getCommit()); 
    this.withCommitter(instance.getCommitter()); 
    this.withMessage(instance.getMessage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.SourceControlUserBuilder author;
  private java.lang.String commit;
  private io.fabric8.openshift.api.model.SourceControlUserBuilder committer;
  private java.lang.String message;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthor instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceControlUser getAuthor() {
    return this.author!=null?this.author.build():null;
  }
  public io.fabric8.openshift.api.model.SourceControlUser buildAuthor() {
    return this.author!=null?this.author.build():null;
  }
  public A withAuthor(io.fabric8.openshift.api.model.SourceControlUser author) {
    _visitables.get("author").remove(this.author);
    if (author!=null){ this.author= new io.fabric8.openshift.api.model.SourceControlUserBuilder(author); _visitables.get("author").add(this.author);} return (A) this;
  }
  public java.lang.Boolean hasAuthor() {
    return this.author != null;
  }
  public A withNewAuthor(java.lang.String email,java.lang.String name) {
    return (A)withAuthor(new SourceControlUser(email, name));
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> withNewAuthor() {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.AuthorNestedImpl();
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> withNewAuthorLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.AuthorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> editAuthor() {
    return withNewAuthorLike(getAuthor());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> editOrNewAuthor() {
    return withNewAuthorLike(getAuthor() != null ? getAuthor(): new io.fabric8.openshift.api.model.SourceControlUserBuilder().build());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<A> editOrNewAuthorLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return withNewAuthorLike(getAuthor() != null ? getAuthor(): item);
  }
  public java.lang.String getCommit() {
    return this.commit;
  }
  public A withCommit(java.lang.String commit) {
    this.commit=commit; return (A) this;
  }
  public java.lang.Boolean hasCommit() {
    return this.commit != null;
  }
  
  /**
   * Method is deprecated. use withCommit instead.
   */
  @java.lang.Deprecated
  public A withNewCommit(java.lang.String arg0) {
    return (A)withCommit(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCommitter instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SourceControlUser getCommitter() {
    return this.committer!=null?this.committer.build():null;
  }
  public io.fabric8.openshift.api.model.SourceControlUser buildCommitter() {
    return this.committer!=null?this.committer.build():null;
  }
  public A withCommitter(io.fabric8.openshift.api.model.SourceControlUser committer) {
    _visitables.get("committer").remove(this.committer);
    if (committer!=null){ this.committer= new io.fabric8.openshift.api.model.SourceControlUserBuilder(committer); _visitables.get("committer").add(this.committer);} return (A) this;
  }
  public java.lang.Boolean hasCommitter() {
    return this.committer != null;
  }
  public A withNewCommitter(java.lang.String email,java.lang.String name) {
    return (A)withCommitter(new SourceControlUser(email, name));
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> withNewCommitter() {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.CommitterNestedImpl();
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> withNewCommitterLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return new io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl.CommitterNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> editCommitter() {
    return withNewCommitterLike(getCommitter());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> editOrNewCommitter() {
    return withNewCommitterLike(getCommitter() != null ? getCommitter(): new io.fabric8.openshift.api.model.SourceControlUserBuilder().build());
  }
  public io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<A> editOrNewCommitterLike(io.fabric8.openshift.api.model.SourceControlUser item) {
    return withNewCommitterLike(getCommitter() != null ? getCommitter(): item);
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitSourceRevisionFluentImpl that = (GitSourceRevisionFluentImpl) o;
    if (author != null ? !author.equals(that.author) :that.author != null) return false;
    if (commit != null ? !commit.equals(that.commit) :that.commit != null) return false;
    if (committer != null ? !committer.equals(that.committer) :that.committer != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(author,  commit,  committer,  message,  additionalProperties,  super.hashCode());
  }
  public class AuthorNestedImpl<N> extends io.fabric8.openshift.api.model.SourceControlUserFluentImpl<io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<N>> implements io.fabric8.openshift.api.model.GitSourceRevisionFluent.AuthorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AuthorNestedImpl(io.fabric8.openshift.api.model.SourceControlUser item) {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this, item);
    }
    AuthorNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this);
    }
    io.fabric8.openshift.api.model.SourceControlUserBuilder builder;
    public N and() {
      return (N) GitSourceRevisionFluentImpl.this.withAuthor(builder.build());
    }
    public N endAuthor() {
      return and();
    }
    
  }
  public class CommitterNestedImpl<N> extends io.fabric8.openshift.api.model.SourceControlUserFluentImpl<io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<N>> implements io.fabric8.openshift.api.model.GitSourceRevisionFluent.CommitterNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CommitterNestedImpl(io.fabric8.openshift.api.model.SourceControlUser item) {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this, item);
    }
    CommitterNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SourceControlUserBuilder(this);
    }
    io.fabric8.openshift.api.model.SourceControlUserBuilder builder;
    public N and() {
      return (N) GitSourceRevisionFluentImpl.this.withCommitter(builder.build());
    }
    public N endCommitter() {
      return and();
    }
    
  }
  
}
